{#
    tinkerbase/aggregated.html
    ~~~~~~~~~~~~~~~~~~~~~~~~~~

    Front page and following pages aggregating multiple posts per page.

    :copyright: Copyright 2011 by Vlad Riscutia
    :license: FreeBSD, see LICENSE file
#}

{% extends "page.html" %}

{%- set archive_title = archive_title is not defined and ' Blog Archive ' or archive_title %}

{% block body %}
    {{ tinkerer_relbar() }}
    {%- for metadata in posts %}
        {{ timestamp(metadata.date, timestamp_format) }}
        {{ metadata.body }}
        {{ post_meta(metadata, metadata.comment_count) }}
        {%- if not loop.last %}<div class="separator post_separator"></div>{%- endif %}
    {%- endfor %}
    {{ tinkerer_relbar() }}
    <div class="archive_link">
        <a href="{{ pathto('archive') }}">{{ archivechar }}{{ archive_title }}{{ archivechar }}</a>
    </div>
{% endblock %}

