{#
    minimal/layout.html
    ~~~~~~~~~~~~~~~~~~~

    Layout for Minimal theme.

    :copyright: Copyright 2011 by Vlad Riscutia
    :license: FreeBSD, see LICENSE file
#}

{% extends "tinkerbase/layout.html" %}

{%- set page_nav_first = True %}

