'''
    Tinkerer Blog
    ~~~~~~~~~~~~~

    Blogging with Sphinx. Like a boss.

    :copyright: Copyright 2011 by Vlad Riscutia
    :license: FreeBSD, see LICENSE file
'''
__version__ = "0.2.1b"

master_doc = "master"
source_suffix = ".rst"
